const express = require('express');
const path = require('path');
const connectDB = require('./mongodb');
const session = require('express-session');
const url = require('url');

const app = express();

// Middleware
app.use(express.json());
app.use(express.static(path.join(__dirname, 'public')));

// Allow only localhost for SSRF protection
function validateLocalhost(req, res, next) {
  const remoteAddress = req.connection.remoteAddress;

  // Allow requests only from localhost (IPv4 and IPv6)
  if (remoteAddress !== '127.0.0.1' && remoteAddress !== '::1') {
    return res.status(403).send('External requests are forbidden');
  }

  next();
}

app.use(validateLocalhost);  // Add the middleware

// Session configuration
app.use(
  session({
    secret: 'session_secret',
    resave: false,
    saveUninitialized: false,
    cookie: { secure: false }
  })
);

// Connection to MongoDB
connectDB();

// Routes
app.use('/api/todos', require('./routes/todos'));
app.use('/api/users', require('./routes/users'));

// Initialize the server
const PORT = process.env.PORT || 3000;
app.listen(PORT, () => console.log(`Server running on port ${PORT}`));
